@@ -1,7 +1,7 @@
 /***************************************************************************
                           version.h  -  description
                              -------------------
-    copyright            : (C) 2007-2020 by Andre Simon
+    copyright            : (C) 2007-2023 by Andre Simon
     email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -25,9 +25,28 @@ along with ANSIFilter.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef VERSION_H
 #define VERSION_H
 
-#define ANSIFILTER_VERSION "2.17"
+#include <string>
+
+#define ANSIFILTER_VERSION "2.19"
 
 #define ANSIFILTER_URL   "http://www.andre-simon.de/"
 #define ANSIFILTER_EMAIL "a.simon@mailbox.org"
 
+class Info
+{
+public:
+
+    static std::string getVersion() {
+        return ANSIFILTER_VERSION;
+    }
+
+    static std::string getWebsite() {
+        return ANSIFILTER_URL;
+    }
+
+    static std::string getEmail() {
+        return ANSIFILTER_EMAIL;
+    }
+};
+
 #endif
